@@ -2,12 +2,12 @@
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
 
-var common = require('../common');
+require('../common');
 var stream = require('../../');
 var assert = require('assert/');
 
 var readable = new stream.Readable({
-  read: common.noop
+  read: function () {}
 });
 
 var errMessage = /Invalid non-string\/buffer chunk/;
